# eric7.RemoteServer.EricServerCoverageRequestHandler

Module implementing the code coverage request handler of the eric-ide server.

### Global Attributes

None

### Classes

EricServerCoverageRequestHandler | Class implementing the code coverage request handler of the eric-ide server.

### Functions

None

## EricServerCoverageRequestHandler

Class implementing the code coverage request handler of the eric-ide server.

### Derived from

EricServerBaseRequestHandler

### Class Attributes

None

### Class Methods

None

### Methods

EricServerCoverageRequestHandler | Constructor
__analyzeDirectory | Private method to analyze files of a directory tree.
__analyzeFile | Private method to analyze a single file.
__analyzeFiles | Private method to analyze a list of files.
__loadCoverageData | Private method to load the data collected by a code coverage run.

### Static Methods

None

#### EricServerCoverageRequestHandler (Constructor)

EricServerCoverageRequestHandler(server)

Constructor

server (EricServer)
  reference to the eric-ide server object

#### EricServerCoverageRequestHandler.__analyzeDirectory

__analyzeDirectory(params)

Private method to analyze files of a directory tree.

params (dict)
  dictionary containing the request data

Return:
  dictionary containing the reply data

Return Type:
  dict

#### EricServerCoverageRequestHandler.__analyzeFile

__analyzeFile(params)

Private method to analyze a single file.

params (dict)
  dictionary containing the request data

Return:
  dictionary containing the reply data

Return Type:
  dict

#### EricServerCoverageRequestHandler.__analyzeFiles

__analyzeFiles(params)

Private method to analyze a list of files.

params (dict)
  dictionary containing the request data

Return:
  dictionary containing the reply data

Return Type:
  dict

#### EricServerCoverageRequestHandler.__loadCoverageData

__loadCoverageData(params)

Private method to load the data collected by a code coverage run.

params (dict)
  dictionary containing the request data

Return:
  dictionary containing the reply data

Return Type:
  dict

Up